@@ -42,9 +42,7 @@ def static_proxy(path):
     if "html" not in path:
         if "admin.js" in path:
             return (
-                render_template("admin.js",
-                                bsVersion=bsVersion,
-                                css_file=css_file),
+                render_template("admin.js", bsVersion=bsVersion, css_file=css_file),
                 200,
                 {"Content-Type": "text/javascript"},
             )
